@@ -108,4 +108,50 @@ print.external_img = function (x, ...){
 }
 
 
+#' @export
+#' @title Word styled text
+#' @description Format a chunk of text with a referenced style.
+#' @param text text value
+#' @param style_id style id
+#' @param style style name. Use only when you don't know what is the id
+#' associated with a stylename.
+#' @param doc \code{rdocx} object where the text will be inserted.
+#' This is only used to get the style id from the style name (use
+#' only when you don't know what is the id associated with a stylename).
+#' @examples
+#' doc <- read_docx()
+#' stext("hello", "strong", doc)
+stext <- function(text, style_id = NULL, style, doc) {
 
+  if( is.null(style_id) ){
+    style_id <- get_style_id(
+      data = doc$styles, style = style, type = "character")
+  }
+
+  out <- list( value = formatC(text), id = style_id )
+  class(out) <- c("stext", "cot")
+  out
+}
+
+
+#' @export
+format.stext = function (x, type = "console", ...){
+  stopifnot( length(type) == 1,
+             type %in% c("wml", "console") )
+
+  if( type == "wml" ){
+    out <- paste0("<w:r>",
+                  sprintf("<w:rPr><w:rStyle w:val=\"%s\"/></w:rPr>", x$id),
+                  "<w:t xml:space=\"preserve\">",
+                  htmlEscape(x$value), "</w:t></w:r>")
+  } else {
+    out <- paste0( "{text:{", x$value, "}}" )
+  }
+
+  out
+}
+
+#' @export
+print.stext = function (x, ...){
+  cat( format(x, type = "console"), "\n", sep = "" )
+}
