@@ -1,19 +1,15 @@
 #' @export
 #' @importFrom utils compareVersion packageVersion
-#' @importFrom R.utils getAbsolutePath
 #' @import zip
 #' @title compress a folder
 #' @description compress a folder to a target file. The
 #' function returns the complete path to target file.
-#' @details
-#' The function is using \link[utils]{zip}, it needs a zip program.
 #' @param folder folder to compress
 #' @param target path of the archive to create
 pack_folder <- function( folder, target ){
-  target <- getAbsolutePath(path.expand(target))
-  folder <- getAbsolutePath(path.expand(folder))
 
-  target <- enc2utf8(target)
+  target <- absolute_path(target)
+
   dir_fi <- dirname(target)
   if( !file.exists(dir_fi) ){
     stop("directory ", shQuote(dir_fi), " does not exist.", call. = FALSE)
@@ -44,7 +40,8 @@ pack_folder <- function( folder, target ){
 
   curr_wd <- getwd()
   setwd(folder)
-
+  if( .Platform$OS.type %in% "windows")
+    target <- enc2native(target)
   tryCatch(
     zip::zip(zipfile = target,
         files = list.files(all.files = TRUE, recursive = TRUE))
@@ -69,22 +66,31 @@ pack_folder <- function( folder, target ){
 #' @param folder folder to create
 unpack_folder <- function( file, folder ){
 
-  file <- getAbsolutePath(path.expand(file))
-  folder <- getAbsolutePath(path.expand(folder))
-
-
   stopifnot(file.exists(file))
 
   unlink(folder, recursive = TRUE, force = TRUE)
 
   unzip( zipfile = file, exdir = folder )
 
-  folder
+  absolute_path(folder)
+}
+
+absolute_path <- function(x){
+
+  if (length(x) != 1L)
+    stop("'x' must be a single character string")
+  epath <- path.expand(x)
+
+  if( file.exists(epath)){
+    epath <- normalizePath(epath, "/", mustWork = TRUE)
+  } else {
+    if( !dir.exists(dirname(epath)) ){
+      stop("directory of ", x, " does not exist.", call. = FALSE)
+    }
+    cat("", file = epath)
+    epath <- normalizePath(epath, "/", mustWork = TRUE)
+    unlink(epath)
+  }
+  epath
 }
 
-# file_path_as_absolute2 <- function(x){
-#   if (length(x) != 1L)
-#     stop("'x' must be a single character string")
-#   epath <- path.expand(x)
-#   normalizePath(epath, "/", mustWork = FALSE)
-# }
