@@ -18,24 +18,25 @@ read_pptx <- function( path = NULL ){
   package_dir <- tempfile()
   unpack_folder( file = path, folder = package_dir )
 
-  obj <- structure(list(package_dir = package_dir),
-                   .Names = c("package_dir"),
-                   class = "rpptx")
+  obj <- list(package_dir = package_dir)
+
 
   obj$table_styles <- read_table_style(package_dir)
 
-  obj$presentation <- presentation$new(obj)
-  obj$slideLayouts <- dir_layout$new(obj )
+  obj$presentation <- presentation$new(package_dir)
 
-  slide_xfrm <- obj$slideLayouts$xfrm()
-  master_xfrm <- obj$slideLayouts$get_master()$xfrm()
+  obj$masterLayouts <- dir_master$new(package_dir, slide_master$new("ppt/slideMasters") )
 
-  obj$slide <- dir_slide$new(obj )
-  obj$content_type <- content_type$new(obj )
+  obj$slideLayouts <- dir_layout$new( package_dir,
+                                      master_metadata = obj$masterLayouts$get_metadata(),
+                                      master_xfrm = obj$masterLayouts$xfrm() )
 
-  obj$core_properties <- core_properties$new(obj$package_dir)
+  obj$slide <- dir_slide$new( package_dir, obj$slideLayouts$get_xfrm_data() )
+  obj$content_type <- content_type$new( package_dir )
+  obj$core_properties <- core_properties$new(package_dir)
 
   obj$cursor = obj$slide$length()
+  class(obj) <- "rpptx"
   obj
 }
 
@@ -74,6 +75,7 @@ print.rpptx <- function(x, target = NULL, ...){
   x$presentation$save()
   x$content_type$save()
 
+  x$slide$save_slides()
   x$core_properties$set_last_modified(format( Sys.time(), "%Y-%m-%dT%H:%M:%SZ"))
   x$core_properties$set_modified_by(Sys.getenv("USER"))
   x$core_properties$save()
@@ -112,7 +114,9 @@ add_slide <- function( x, layout, master ){
   # update presentation elements
   x$presentation$add_slide(target = file.path( "slides", new_slidename) )
   x$content_type$add_slide(partname = file.path( "/ppt/slides", new_slidename) )
-  x$slide$update()
+
+  x$slide$add_slide(xml_file, x$slideLayouts$get_xfrm_data() )
+
   x$cursor = x$slide$length()
   x
 
@@ -184,7 +188,7 @@ remove_slide <- function( x, index = NULL ){
     stop("unvalid index ", index, " (", l_," slide(s))", call. = FALSE)
   }
 
-  del_file <- x$slide$remove(index)
+  del_file <- x$slide$remove_slide(index)
   # update presentation elements
   x$presentation$remove_slide(del_file)
   x$content_type$remove_slide(partname = del_file )
@@ -224,7 +228,6 @@ layout_properties <- function( x, layout = NULL, master = NULL ){
   data <- x$slideLayouts$get_xfrm_data()
 
   if( !is.null(layout) && !is.null(master) ){
-
     data <- data[data$name == layout & data$master_name == master,]
   } else if( is.null(layout) && !is.null(master) ){
     data <- data[data$master_name == master,]
@@ -362,5 +365,5 @@ slide_summary <- function( x, index = NULL ){
 #' x <- read_pptx()
 #' color_scheme ( x = x )
 color_scheme <- function( x ){
-  x$slideLayouts$get_master()$get_color_scheme()
+  x$masterLayouts$get_color_scheme()
 }
